@@ -75,14 +75,14 @@ GameScene::GameScene(Game* p_game, KGameThemeProvider* p_themeProvider) : m_game
     }
 
     // The remaining time
-    m_remainingTimeLabel = new QGraphicsTextItem(i18n("0:00"));
+    m_remainingTimeLabel = new QGraphicsTextItem();
     m_remainingTimeLabel->setFont(QFont(QStringLiteral("Helvetica"), static_cast<int>(Granatier::CellSize * 0.35), QFont::Bold, false));
-    m_remainingTimeLabel->setDefaultTextColor(QColor("#FFFF00"));
+    m_remainingTimeLabel->setDefaultTextColor(QColor(0xFF, 0xFF, 0x00));
     m_remainingTimeLabel->setZValue(1000);
 
-    m_arenaNameLabel = new QGraphicsTextItem(i18n("Arena Name"));
+    m_arenaNameLabel = new QGraphicsTextItem();
     m_arenaNameLabel->setFont(QFont(QStringLiteral("Helvetica"), static_cast<int>(Granatier::CellSize * 0.35), QFont::Bold, false));
-    m_arenaNameLabel->setDefaultTextColor(QColor("#FFFF00"));
+    m_arenaNameLabel->setDefaultTextColor(QColor(0xFF, 0xFF, 0x00));
     m_arenaNameLabel->setZValue(1000);
 
     // setup the theme renderer
@@ -210,7 +210,7 @@ void GameScene::init()
     {
         addItem(m_remainingTimeLabel);
     }
-    m_remainingTimeLabel->setDefaultTextColor(QColor("#FFFF00"));
+    m_remainingTimeLabel->setDefaultTextColor(QColor(0xFF, 0xFF, 0x00));
     int nTime = m_game->getRemainingTime();
     m_remainingTimeLabel->setPlainText(QStringLiteral("%1:%2").arg(nTime/60).arg(nTime%60, 2, 10, QLatin1Char('0')));
     m_remainingTimeLabel->setPos(Granatier::CellSize * m_game->getArena()->getNbColumns() - m_remainingTimeLabel->boundingRect().width(), - m_remainingTimeLabel->boundingRect().height());
@@ -269,7 +269,7 @@ void GameScene::initItemsWithGraphicsFromTheme()
         for (int j = 0; j < m_game->getArena()->getNbColumns(); ++j)
         {
             // Create the ArenaItem and set the image
-            auto* arenaItem = new ArenaItem(j * Granatier::CellSize, i * Granatier::CellSize, m_rendererArenaItems, QStringLiteral(""));
+            auto* arenaItem = new ArenaItem(j * Granatier::CellSize, i * Granatier::CellSize, m_rendererArenaItems, QString());
             connect(this, &GameScene::resizeGraphics, arenaItem, &ArenaItem::updateGraphics);
 
             //TODO: use this function call
@@ -814,7 +814,7 @@ void GameScene::updateInfo(const Granatier::Info::Type p_info)
         else
         {
             m_remainingTimeLabel->setPlainText(i18n("Sudden Death"));
-            m_remainingTimeLabel->setDefaultTextColor(QColor("#FF0000"));
+            m_remainingTimeLabel->setDefaultTextColor(QColor(0xFF, 0x00, 0x00));
             m_remainingTimeLabel->setPos(Granatier::CellSize * m_game->getArena()->getNbColumns() - m_remainingTimeLabel->boundingRect().width(), - m_remainingTimeLabel->boundingRect().height());
         }
     }
